All Classes and Interfaces
Class
Description
In memory representation of a Java class.
An immutable collection of
ClassFile instances.Exception thrown when code cannot compile.
Fully compiled results provided from a
TestCompiler.Adapter class that can be used to apply AOT
GeneratedFiles to the
TestCompiler.Annotation that registers a JUnit Jupiter extension for test classes or test
methods that need to use a forked classloader with compiled code.
ClassLoader used to expose dynamically generated content.Abstract base class for dynamically generated files.
Assertion methods for
DynamicFile instances.@EnabledIfRuntimeHintsAgent signals that the annotated test class or test method
is only enabled if the RuntimeHintsAgent is loaded on the current JVM.Main types of
RuntimeHints.Deprecated.
This class should only be used by the runtime-hints agent when instrumenting bytecode
and is not considered public API.
Reference to a Java method, identified by its owner class and the method name.
Simple mock
SpringFactoriesLoader implementation that can be used for testing
purposes.Record of an invocation of a method relevant to
RuntimeHints.Builder for
RecordedInvocation.Listener for
invocations recorded by the RuntimeHintsAgent.Publishes invocations on method relevant to
RuntimeHints,
as they are recorded by the RuntimeHintsAgent.DynamicFile that holds resource file content and provides
ResourceFileAssert support.Assertion methods for
ResourceFile instances.An immutable collection of
ResourceFile instances.Java Agent that records method invocations related to
RuntimeHints metadata.A wrapper for
RecordedInvocation that is the starting point for
RuntimeHints AssertJ assertions.AssertJ
assertions that can be applied to
RuntimeHintsInvocations.Invocations relevant to
RuntimeHints recorded during the execution of a block
of code instrumented by the RuntimeHintsAgent.DynamicFile that holds Java source code and provides
SourceFileAssert support.Assertion methods for
SourceFile instances.An immutable collection of
SourceFile instances.Utility that can be used to dynamically compile and test Java source code.
GenerationContext test implementation that uses
InMemoryGeneratedFiles and can configure a TestCompiler
instance.Callback interface used to write file content.